==> nf_presentation-0.3.0.dev3.tar.gz: nf_presentation-0.3.0.dev3/src/nf_presentation/settings.py <==
#
# Output formatting
#

#presentation
PRESENTATION_RATIO='16:9'
#Title list

LOGO_POSITION=(0.5,0.5)
LOGO_WIDTH=(12)

NAME_POSITION=(12,12)

#Exercises
#title
TITLE_POSITION=(0.5,0.5)
TITLE_SIZE=(33,1)
TITLE_BACKGROUND=(46,117,182)
TITLE_FOREGROUND=(255,255,255)

# left side
SCHEME_POSITION=(12.0,2.0)
SCHEME_HEIGHT=8.5 # not used atm
SCHEME_WIDTH=21.5


ADDITIONAL_TABLE_POSITION=(0.5,2.0)
ADDITIONAL_TABLE_WIDTH=10.5


#right side

BASIC_TABLE_POSITION=(12.0,2.0)
BASIC_TABLE_WIDTH=21.5

LINKS_TABLE_POSTION=(12,16.8)
LINKS_TABLE_WIDTH=21.5

DEFAULT_SLIDE_TITLE='Основная часть'

# PRESENTATION SETTINGS

DEFAULT_TITLE='---' #TODO default value for non found items
DEFAULT_TITLE_FONT_SIZE_PT=18
DEFAULT_TEXT_FONT_SIZE_PT=12

DEFAULT_TABLE_WIDTH=3
DEFAULT_TABLE_ROW_HEIGHT=0.4
DEFAULT_TABLE_HORZ_BANDING=False  # rows alternates color if True
DEFAULT_TABLE_MARK_FIRST_ROW=False  # highlights first row with alternative color if True


#DATA
EMPY_DESCRIPLION_REPLACEMENT='Пустое описание'  # if description is empty or None
UNKNOWN_GROUP_ID_NAME_REPLACEMENT='?'
EMPTY_TRAINER_NAME_REPLACEMENT=''


#FILES
RFS_LOGO_FILE_NAME='rfs_logo.png'

# SVG SETTINGS
svg_replacements={
    'markerwidth':'markerWidth',
    'markerheight':'markerHeight',
    'viewbox':'viewBox',
    'refx':'refX',
    'refy':'refY',
    #fix for ellipse in rings (adding preserveration attribute where href=.../ring/022_2.svg)
    #for red ones
    '/ring/o22_2.svg"':'/ring/o22_2.svg" preserveAspectRatio="xMaxYMid meet"',
    #for yellow
    '/ring/o22_1.svg"':'/ring/o22_1.svg" preserveAspectRatio="xMaxYMid meet"',
    #for potential othe types black, green, etc(doing it blindly)
    '/ring/o22_0.svg"':'/ring/o22_0.svg" preserveAspectRatio="xMaxYMid meet"',
    '/ring/o22_3.svg"':'/ring/o22_0.svg" preserveAspectRatio="xMaxYMid meet"',
    '/ring/o22_4.svg"':'/ring/o22_0.svg" preserveAspectRatio="xMaxYMid meet"',
    '/ring/o22_5.svg"':'/ring/o22_0.svg" preserveAspectRatio="xMaxYMid meet"'

}

png_render_width=600
png_render_height=400

def add_svg_replacement(old:str,new:str):
    svg_replacements[old]=new

==> nf_presentation-0.3.2.tar.gz: nf_presentation-0.3.2/src/nf_presentation/settings.py <==
#
# Output formatting
#

#presentation
PRESENTATION_RATIO='16:9'
#Title list

LOGO_POSITION=(0.5,0.5)
LOGO_WIDTH=(12)

NAME_POSITION=(12,12)

#Exercises
#title
TITLE_POSITION=(0.5,0.5)
TITLE_SIZE=(33,1)
TITLE_BACKGROUND=(46,117,182)
TITLE_FOREGROUND=(255,255,255)

# left side
SCHEME_POSITION=(12.0,2.0)
SCHEME_HEIGHT=8.5 # not used atm
SCHEME_WIDTH=21.5


ADDITIONAL_TABLE_POSITION=(0.5,2.0)
ADDITIONAL_TABLE_WIDTH=10.5


#right side

BASIC_TABLE_POSITION=(12.0,2.0)
BASIC_TABLE_WIDTH=21.5

LINKS_TABLE_POSTION=(12,16.8)
LINKS_TABLE_WIDTH=21.5

#DEFAULT_SLIDE_TITLE='Основная часть'

# PRESENTATION SETTINGS

DEFAULT_TITLE='---' #TODO default value for non found items
DEFAULT_TITLE_FONT_SIZE_PT=18
DEFAULT_TEXT_FONT_SIZE_PT=12

DEFAULT_TABLE_WIDTH=3
DEFAULT_TABLE_ROW_HEIGHT=0.4
DEFAULT_TABLE_HORZ_BANDING=False  # rows alternates color if True
DEFAULT_TABLE_MARK_FIRST_ROW=False  # highlights first row with alternative color if True


#DATA
EMPY_DESCRIPLION_REPLACEMENT='Пустое описание'  # if description is empty or None
UNKNOWN_GROUP_ID_NAME_REPLACEMENT='?'
EMPTY_TRAINER_NAME_REPLACEMENT=''


#FILES
RFS_LOGO_FILE_NAME='rfs_logo.png'

# SVG SETTINGS
svg_replacements={
    'markerwidth':'markerWidth',
    'markerheight':'markerHeight',
    'viewbox':'viewBox',
    'refx':'refX',
    'refy':'refY',
    #fix for ellipse in rings (adding preserveration attribute where href=.../ring/022_2.svg)
    #for red ones
    '/ring/o22_2.svg"':'/ring/o22_2.svg" preserveAspectRatio="xMaxYMid meet"',
    #for yellow
    '/ring/o22_1.svg"':'/ring/o22_1.svg" preserveAspectRatio="xMaxYMid meet"',
    #for potential othe types black, green, etc(doing it blindly)
    '/ring/o22_0.svg"':'/ring/o22_0.svg" preserveAspectRatio="xMaxYMid meet"',
    '/ring/o22_3.svg"':'/ring/o22_0.svg" preserveAspectRatio="xMaxYMid meet"',
    '/ring/o22_4.svg"':'/ring/o22_0.svg" preserveAspectRatio="xMaxYMid meet"',
    '/ring/o22_5.svg"':'/ring/o22_0.svg" preserveAspectRatio="xMaxYMid meet"',
    # a fix for longer gates
    '/img/gate/2/gt09.svg"':'/img/gate/2/gt09.svg" preserveAspectRatio="xMaxYMid meet"',
    #we need a bigger replace for all stuff
    #maybe all preserveraspectratio to all svg

    #replace for polygons that were black because of opacity bug in cairo
    #bugfix 0.3.0dev9
    ";fill:#0000001a\"":"\" fill='#000000' fill-opacity='0.1'", #black
    ";fill:#ffff001a\"":"\" fill='#ffff00' fill-opacity='0.1'", #yellow one
    #will be problems with other polygon colors
    # in newer schemes this syntax is used style="...; fill: rgba(255, 255, 0, 0.1)"
    # and cairo eats it
    # maybe i need a chemeBugfix class lol instead a list of replacements, some bugfix are more complex

}

png_render_width=600
png_render_height=400

def add_svg_replacement(old:str,new:str):
    svg_replacements[old]=new
